@@ -846,7 +846,7 @@ int  conv_array_float(output_pp,array_str,i_cnt) float  **output_pp; char *array
         sscanf(mem_p->s_name,fmt_str, &a_idx);
         if( (1 <= a_idx) && (a_idx <= i_cnt) ) {
           switch(mem_p->s_type) {
-            case IDENTIFIER:                  break; /* do nothing, let later routing catch this error */
+            case IDENTIFIER:        break; /* do nothing, let later routing catch this error */
             case I_VAR: case I_CONSTANT: 
               (*output_pp)[a_idx-1] = (float)mem_p->s_int;
               conv_cnt++;
@@ -855,7 +855,7 @@ int  conv_array_float(output_pp,array_str,i_cnt) float  **output_pp; char *array
               (*output_pp)[a_idx-1] = mem_p->s_real;
               conv_cnt++;
               break;
-            case S_VAR: case S_CONSTANT:      break; /* do nothing, let later routing catch this error */
+            case S_VAR: case S_CONSTANT:   break; /* do nothing, let later routing catch this error */
           }
         }
       } /* end for mem_p */
@@ -954,7 +954,7 @@ char *output_p;char *seed;int item_cnt;int dimen;char *m_vec_str;char *c_vec_str
     r_vec = (float *)capa_malloc(sizeof(float),dimen); /* resulting point vector */
     t_vec = (float *)capa_malloc(sizeof(float),dimen); /* working area point vector */
     
-
+    /* set the random number seed */
     setgmn(m_vec,c_vec,(long)dimen,param_vec);
 
     for(i=0;i<total_cnts;) {
@@ -1875,13 +1875,13 @@ gen_ptslist_str( range_str ) char *range_str;
     cp = range_str;
     i  = 0;
     while( isspace(*cp) || (*cp == '"') ) { cp++; }
-    while( isdigit(*cp) || *cp == '.' || *cp == ',' || isspace(*cp) ) {
+    while( isdigit(*cp) || *cp == '-' || *cp == '.' || *cp == ',' || isspace(*cp) ) {
       p1[i++] =  *cp; cp++;
     }
     p1[i] = 0;
     while( isspace(*cp) || (*cp == '"') || (*cp == ':')) { cp++; }
     i = 0;
-    while( isdigit(*cp) || *cp == '.' || *cp == ',' || isspace(*cp) ) {
+    while( isdigit(*cp) || *cp == '-' || *cp == '.' || *cp == ',' || isspace(*cp) ) {
       p2[i++] =  *cp; cp++;
     }
     p2[i] = 0;
@@ -1897,7 +1897,7 @@ gen_ptslist_str( range_str ) char *range_str;
     i = 0;
     cp = range_str;
     while( isspace(*cp) || (*cp == '"') ) { cp++; }
-    while( isdigit(*cp) || *cp == '.' || *cp == ',' || isspace(*cp) ) {
+    while( isdigit(*cp) || *cp =='-' || *cp == '.' || *cp == ',' || isspace(*cp) ) {
       p1[i++] =  *cp; cp++;
     }
     p1[i] = 0;
