@@ -764,7 +764,7 @@ char *log_string;
    tmtime=localtime(&t);
    strftime(timeStr,FILE_NAME_LENGTH,"%d/%m %X",tmtime);
    /*ct[ strlen(ct)-1 ]=0;*/ /* Trash newline */
-   protect_log_string(log_string);
+   /*protect_log_string(log_string);*/
    fprintf(fp,"%s\t%s\t%s\n",student_number,timeStr,log_string); fflush(fp);
    fclose(fp);
    return (0);
@@ -1589,7 +1589,7 @@ int   *section;
 int    prob;
 {
   int i,length;
-  char date_str[DATE_LENGTH];
+  char date_str[DATE_LENGTH],*tmp;
   char **sbuf_pp,answer[(EDIT_HEIGHT*(EDIT_WIDTH+1))+1];
   char submissions_str[(EDIT_HEIGHT*(EDIT_WIDTH+1))+MAX_BUFFER_SIZE];
   time_t     curtime;
@@ -1615,7 +1615,10 @@ int    prob;
     capa_mfree((char *)sbuf_pp[i]);
   }
   capa_set_subjective(set,prob,student_number,answer);
-  sprintf(submissions_str,"%d\t%s\t",prob,answer);
+  tmp=strsave(answer);
+  protect_log_string(tmp);
+  sprintf(submissions_str,"%d\t%s\t",prob,tmp);
+  capa_mfree(tmp);
   log_submissions(student_number,set,submissions_str);
   capa_mfree((char *)sbuf_pp);
   return 1;
@@ -1655,7 +1658,7 @@ int   *section;
    T_entry    entry;
    char       answer[256], *a_str, **ans_strs;
    int        num, offset, num_questions, start_from, leng;
-   char      *log_string,submissions_str[MAX_BUFFER_SIZE];
+   char      *log_string,submissions_str[MAX_BUFFER_SIZE],*tmp;
    int       *tried,answered;
    int        scr_idx=1, display=1, second_scr, canAnswer;
    int        usr_command, whereto, allow_hint=0, ex=0;
@@ -1860,8 +1863,10 @@ int   *section;
 		  if ( is_all_ws(ans_strs[0]) )  break;
 		  trim_response_ws(ans_strs[0]);
 		}
-		
-		sprintf(submissions_str,"%d\t%s\t",num+1,a_str);
+		tmp=strsave(a_str);
+		protect_log_string(tmp);
+		sprintf(submissions_str,"%d\t%s\t",num+1,tmp);
+		capa_mfree(tmp);
 		log_submissions(student_number,set,submissions_str);
 
 		{
@@ -1910,11 +1915,14 @@ int   *section;
                 /* ------------------------------ check due date */
                 time(&curtime);
                 /* ===> if (compare_datetime(curtime,header.due_date) > 0) { */
+#ifndef NO_DATE_CHECK
                 if( capa_check_date(CHECK_DUE_DATE,student_number,*section,set) > 0 ) {
                   capa_get_date(CHECK_DUE_DATE,student_number,*section,set,date_str);
                   sprintf(answer,"Sorry, the due date was: %s",date_str);
                   move(20,1); clrtobot(); addstr(answer); mypause(23,1);
-                } else {
+                } else
+#endif
+                {
                   capa_set_entry(&entry,student_number,set,offset);
                 }
               } break;
